@@ -13,6 +13,10 @@ from collections import deque
 from wand.image import Image
 
 from .plotter import create_tree_diagram
+from .style import (
+	ConnectorStyle,
+	NodeStyle
+)
 
 class NodeException(Exception):
 	pass
@@ -148,10 +152,27 @@ class Tree:
 	connector_type : str
 		The connector type of the tree, i.e. the Treant style used in the visualization. Common
 		options are `"curved"`, `"bCurve"`, `"step"`, and `"straight"`.
+	connector_style : style.ConnectorStyle
+		An optional `style.ConnectorStyle` object. Comes from the Raphaël package.
+	orientation : str
+		Orientation of the tree in the visualization. Options are `"north"`, `"east"`,
+		`"south"`, and "`west`".
+	node_style: style.NodeStyle
+		An optional `style.NodeStyle` object. Determines what the nodes in the tree will look like.
 	"""
-	def __init__(self, root=None, connector_type="curved"):
+	def __init__(
+			self,
+			root=None,
+			connector_type="curved",
+			connector_style=ConnectorStyle(),
+			orientation="north",
+			node_style=NodeStyle()
+		):
 		self.root = root
 		self.connector_type = connector_type
+		self.connector_style = connector_style
+		self.orientation = orientation
+		self.node_style = node_style
 
 	def __repr__(self):
 		return '<tree.Tree nodes={}>'.format(self.size())
